video_extensions = (".avi", ".mp4")
config_extension = ".json"
results_extension = ".h5"
